@@ -16,7 +16,7 @@ our @EXPORT = qw(
                  reset_all_test_coverage
                  test_coverage_except
                 );
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my $self    = {};
 my $test    = Test::Builder->new();
@@ -24,7 +24,7 @@ my $invokes = {};
 my $last    = '';
 
 
-sub test_coverage{
+sub test_coverage {
     my ($package) = @_;
     return unless defined $package;
     $last = $package;
@@ -49,20 +49,20 @@ sub test_coverage{
     1;
 }
 
-sub test_coverage_except{
-    my ($self,$package,@subroutines) = @_;
+sub test_coverage_except {
+    my ($package,@subroutines) = @_;
     
     for my $subname(@subroutines){
         if(exists $invokes->{$package} and 
            exists $invokes->{$package}->{$subname} and
            exists $self->{subs}->{$package}){
-            @{$self->{subs}->{$package}} = grep{$_ ne $subname}@{$self->{subs}->{$package}};
+            @{$self->{subs}->{$package}} = grep{$_->[0] ne $subname}@{$self->{subs}->{$package}};
             delete $invokes->{$package}->{$subname};
         }
     }
 }
 
-sub all_test_coverage_ok{
+sub all_test_coverage_ok {
     my ($msg) = @_;
     
     for my $package(keys %$invokes){
